Instalación de ONLYOFFICE Apps Developer con parámetros adicionales de script
Introducción
ONLYOFFICE Apps Developer es una versión de pago de un centro de documentos donde puedes conectar usuarios y documentos en un solo lugar para mejorar la colaboración.
ONLYOFFICE Apps Developer se distribuye como un script de instalación automática para sistemas operativos Linux con Docker instalado. El script configurará contenedores Docker con todos los componentes necesarios para el correcto funcionamiento de ONLYOFFICE Apps Developer y es fácil de ejecutar, gestionar y actualizar.
Después de descargar el script de instalación de ONLYOFFICE Apps Developer, es posible que necesites ejecutarlo especificando algunos parámetros adicionales, por ejemplo, si deseas instalar cada componente en una máquina separada.
Usa el siguiente comando para mostrar la lista de todos los parámetros disponibles del script Docker:
bash apps-developer-install.sh docker -h
Usa el siguiente comando para mostrar la lista de todos los parámetros disponibles del script DEB/RPM:
bash apps-developer-install.sh package -h
A continuación, puedes encontrar una breve descripción y algunos ejemplos de uso para estos parámetros.
Cuando ejecutes el script con parámetros, se te pedirá que selecciones la forma en que deseas instalar ONLYOFFICE Apps. Escribe Y y presiona Enter para instalar ONLYOFFICE Apps usando Docker. Escribe N y presiona Enter para instalar ONLYOFFICE Apps desde paquetes DEB/RPM.
Credenciales
| Parámetro | Descripción |
|---|---|
-reg, --registry | URL del registro docker (por ejemplo, https://myregistry.com:5000) |
-un, --username | usuario del registro docker |
-p, --password | contraseña del registro docker |
Estos parámetros se utilizan en caso de que te proporcionemos credenciales para acceder a un repositorio de prueba para que puedas ejecutar contenedores desde imágenes almacenadas en él.
Ejemplo
bash apps-developer-install.sh -reg URL -un username -p password
Tipo de instalación
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-it, --installationtype | tipo de instalación | community|developer|enterprise | developer |
Este parámetro te permite instalar la solución especificada: ONLYOFFICE Apps Community, ONLYOFFICE Apps Developer o ONLYOFFICE Apps Enterprise.
Ejemplo
bash apps-developer-install.sh -it community
Esto instalará la solución ONLYOFFICE Apps Community.
Verificación de hardware
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-skiphc, --skiphardwarecheck | usar para omitir la verificación de hardware | true|false | false |
Este parámetro te permite omitir la verificación de si el sistema cumple con los requisitos mínimos de hardware.
Ejemplo
bash apps-developer-install.sh -skiphc true
Esto omitirá la verificación de hardware.
Actualización de componentes
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-u, --update | usar para actualizar componentes existentes | true|false | false |
Este parámetro te permite instalar las últimas versiones de los componentes necesarios si los componentes correspondientes instalados en tu máquina están desactualizados.
Ejemplo
bash apps-developer-install.sh -u true
Esto detendrá los contenedores que necesiten ser actualizados, los eliminará y luego ejecutará las últimas versiones de los componentes correspondientes de ONLYOFFICE Apps Developer. Si la versión actual del componente coincide con la última disponible, dicho contenedor no se verá afectado. Si has omitido algunos componentes durante la instalación anterior, también serán omitidos. Los datos de ONLYOFFICE Apps deberían recogerse automáticamente.
Actualiza solo Docs a la versión 7.2.1.34 y omite la actualización de todos los demás componentes:
bash apps-developer-install.sh -u true -docsi onlyoffice/documentserver-de -docsv 7.2.1.34 -idocs true -ia false -irbt false -irds false
Actualiza solo ONLYOFFICE Apps a la versión 1.2.0 y omite la actualización de todos los demás componentes:
bash apps-developer-install.sh -u true -asv v1.2.0 -idocs false -irbt false -irds false
Instalación de componentes
| Parámetro | Descripción | Valores | Predeterminado |
|---|---|---|---|
-ia, --installapps | instalar ONLYOFFICE Apps | true|false | true |
-idocs, --installdocs | instalar ONLYOFFICE Docs | true|false | true |
-irbt, --installrabbitmq | instalar RabbitMQ | true|false | true |
-irds, --installredis | instalar Redis | true|false | true |
-imysql, --installmysql | instalar MySQL | true|false | true |
Estos parámetros te permiten especificar si necesitas instalar un componente determinado o no. Pueden usarse si deseas instalar cada componente en una máquina separada.
- Usa el valor
truepara instalar un componente. - Usa el valor
falsepara omitir la instalación de un componente.
Ejemplo
bash apps-developer-install.sh -idocs false
Esto instalará todos los componentes de ONLYOFFICE Apps Developer sin ONLYOFFICE Docs.
bash apps-developer-install.sh -ia false -idocs true -imysql false -irbt false -irds false
Esto omitirá la instalación de ONLYOFFICE Apps, MySQL, RabbitMQ y Redis e instalará solo ONLYOFFICE Docs.
Versión de componentes
| Parámetro | Descripción |
|---|---|
-asv, --appsversion | versión de ONLYOFFICE Apps |
-docsv, --docsversion | versión de ONLYOFFICE Docs |
Estos parámetros se pueden usar para instalar una cierta versión de ONLYOFFICE Apps o ONLYOFFICE Docs si por alguna razón no deseas instalar la última versión disponible en el repositorio. Por defecto, se utiliza una imagen etiquetada como latest para ejecutar el contenedor del componente.
Ejemplo
Abre el repositorio de Docker Hub en tu navegador, selecciona ONLYOFFICE Docs y ve a la pestaña Tags para ver todas las etiquetas disponibles en el repositorio. Especifica la versión que deseas instalar:
bash apps-developer-install.sh -docsv 7.2.1.34
Esto instalará ONLYOFFICE Apps con la versión 7.2.1.34 de ONLYOFFICE Docs.
Nombre de la imagen de ONLYOFFICE Docs
| Parámetro | Descripción |
|---|---|
-docsi, --docsimage | Nombre de la imagen de ONLYOFFICE Docs |
Este parámetro se puede usar para especificar un nombre de la imagen de ONLYOFFICE Docs desde la cual debería iniciarse un contenedor. La imagen especificada debe estar almacenada en nuestro repositorio público oficial en Docker Hub.
Ejemplo
bash apps-developer-install.sh -docsi onlyoffice/documentserver-de
Esto ejecutará un contenedor desde la imagen especificada de ONLYOFFICE Docs almacenada en el repositorio.
Configuración para hosts
| Parámetro | Descripción |
|---|---|
-ash, --appshost | Host de ONLYOFFICE Apps |
-esh, --elastichost | Hosts de OpenSearch |
Estos parámetros se pueden usar para conectar los componentes si los instalas en máquinas separadas.
Ejemplo
bash apps-developer-install.sh -esh 192.168.3.202
Esto instalará ONLYOFFICE Apps y lo conectará con OpenSearch instalado en una máquina diferente que tiene la dirección IP 192.168.3.202.
Configuración para core.machinekey
| Parámetro | Descripción |
|---|---|
-mk, --machinekey | Configuración para la clave core.machinekey |
Este parámetro te permite especificar tu propia machinekey al instalar ONLYOFFICE Apps Developer.
Este parámetro se escribe en el archivo de configuración /app/onlyoffice/config/appsettings.json (la ruta se especifica dentro del contenedor onlyoffice-studio).
Ejemplo
bash apps-developer-install.sh -mk yourmachinekey
Puerto externo de ONLYOFFICE Apps
| Parámetro | Descripción | Por defecto |
|---|---|---|
-ep, --externalport | Puerto externo de ONLYOFFICE Apps | 80 |
Este parámetro te permite cambiar el puerto en el que se ejecutará ONLYOFFICE Apps. Por defecto, se utiliza el puerto 80.
Ejemplo
bash apps-developer-install.sh -ep 8080
Configuración para el encabezado y secreto JWT
| Parámetro | Descripción |
|---|---|
-jh, --jwtheader | Configuración para el encabezado JWT |
-js, --jwtsecret | Configuración para la clave secreta JWT |
Estos parámetros te permiten especificar el encabezado JWT y tu propia clave secreta JWT al instalar ONLYOFFICE Apps Developer. El encabezado JWT define el encabezado http que se utilizará para enviar el JWT. La clave secreta se utiliza para firmar el token web JSON y validar el token al solicitarlo a ONLYOFFICE Docs.
Estos parámetros se escriben en los siguientes archivos de configuración (las rutas se especifican dentro de los contenedores onlyoffice-studio y onlyoffice-document-server):
- Para ONLYOFFICE Apps -
/app/onlyoffice/config/appsettings.json - Para Servidor de documentos -
/etc/onlyoffice/documentserver/local.json
Ejemplo
bash apps-developer-install.sh -js yoursecret
Servidor MySQL
| Parámetro | Descripción | Por defecto |
|---|---|---|
-mysqlrp, --mysqlrootpassword | Contraseña root del servidor MySQL | generado automáticamente |
-mysqlh, --mysqlhost | Host del servidor MySQL | localhost |
-mysqlport, --mysqlport | Número de puerto del servidor MySQL | 3306 |
Si no especificas explícitamente el host y el puerto, se utilizan los valores por defecto. La contraseña root se genera automáticamente si no la estableces.
Ejemplo
bash apps-developer-install.sh -mysqlrp new-secret-pw
Este comando te permite establecer tu propia contraseña para la cuenta root de MySQL durante la instalación de ONLYOFFICE Apps Developer.
Base de datos de ONLYOFFICE Apps
| Parámetro | Descripción | Por defecto |
|---|---|---|
-mysqld, --mysqldatabase | Nombre de la base de datos de ONLYOFFICE Apps | onlyoffice_apps |
-mysqlu, --mysqluser | Usuario de la base de datos de ONLYOFFICE Apps | - |
-mysqlp, --mysqlpassword | Contraseña de la base de datos de ONLYOFFICE Apps | generado automáticamente |
Estos parámetros te permiten crear la base de datos de ONLYOFFICE Apps especificando un nombre de base de datos personalizado, así como un nombre de usuario y contraseña para la cuenta con permisos de superusuario en la base de datos creada. Si no especificas explícitamente el nombre de la base de datos, se utiliza el valor por defecto. Si no estableces una contraseña, se genera automáticamente.
Ejemplo
bash apps-developer-install.sh -mysqld appsdatabase -mysqlu username -mysqlp password
Servidor RabbitMQ
| Parámetro | Descripción | Por defecto |
|---|---|---|
--rabbitmqprotocol | Protocolo de conexión de RabbitMQ | amqp |
--rabbitmqhost | Host del servidor RabbitMQ | localhost |
--rabbitmqport | Número de puerto del servidor RabbitMQ | 5672 |
--rabbitmqusername | Nombre de usuario de RabbitMQ | - |
--rabbitmqpassword | Contraseña del usuario de RabbitMQ | - |
--rabbitmqvirtualhost | Host virtual de RabbitMQ | / |
Usa estos parámetros para conectar ONLYOFFICE Apps a un servidor RabbitMQ que ya se está ejecutando en otra máquina. Omite la instalación de RabbitMQ con el parámetro -irbt false y luego especifica los parámetros de conexión de tu propio servidor. Si no especificas explícitamente el protocolo, el host, el puerto o el host virtual, se utilizan los valores por defecto.
Ejemplo
bash apps-developer-install.sh -irbt false --rabbitmqhost mq.example.com --rabbitmqusername username --rabbitmqpassword password
Esto instalará ONLYOFFICE Apps sin RabbitMQ y lo conectará con el servidor RabbitMQ que se ejecuta en el host mq.example.com.
Servidor Redis
| Parámetro | Descripción | Por defecto |
|---|---|---|
--redishost | Host del servidor Redis | localhost |
--redisport | Número de puerto del servidor Redis | 6379 |
--redisusername | Nombre de usuario de Redis, si el servidor requiere autorización | - |
--redispassword | Contraseña del usuario de Redis, si el servidor requiere autorización | - |
Usa estos parámetros para conectar ONLYOFFICE Apps a un servidor Redis que ya se está ejecutando en otra máquina. Omite la instalación de Redis con el parámetro -irds false y luego especifica los parámetros de conexión de tu propio servidor. El nombre de usuario y la contraseña solo son necesarios si tu servidor Redis requiere autorización.
Ejemplo
bash apps-developer-install.sh -irds false --redishost redis.example.com --redispassword password
Esto instalará ONLYOFFICE Apps sin Redis y lo conectará con el servidor Redis que se ejecuta en el host redis.example.com.
Servidor OpenSearch
| Parámetro | Descripción | Por defecto |
|---|---|---|
--elasticprotocol | Protocolo de conexión de OpenSearch | http |
--elasticport | Número de puerto del servidor OpenSearch | 9200 |
Usa estos parámetros junto con el parámetro -esh, --elastichost descrito en la sección «Configuración para hosts» más arriba para conectar ONLYOFFICE Apps a un servidor OpenSearch que se ejecuta en otra máquina. Si no especificas explícitamente el protocolo y el puerto, se utilizan los valores por defecto.
Ejemplo
bash apps-developer-install.sh -esh search.example.com --elasticprotocol https --elasticport 9200
Esto conectará ONLYOFFICE Apps con el servidor OpenSearch que se ejecuta en el host search.example.com mediante HTTPS.
Cambio a HTTPS
| Parámetro | Descripción |
|---|---|
-led, --letsencryptdomain | define el dominio para el certificado de Let's Encrypt |
-lem, --letsencryptmail | define la dirección de correo del administrador del dominio para el certificado de Let's Encrypt |
-cf, --certfile | ruta al archivo del certificado para el dominio |
-ckf, --certkeyfile | ruta al archivo de clave privada para el certificado |
Estos parámetros te permiten cambiar el espacio de trabajo a HTTPS. Solo se pueden usar para la versión Docker.
Ejemplo
bash apps-developer-install.sh docker --letsencryptmail user@example.com --letsencryptdomain yourdomain.com
Esto creará e instalará automáticamente el certificado firmado por la CA de letsencrypt.org en tu servidor y reiniciará el servicio NGINX para que los cambios surtan efecto.
bash apps-developer-install.sh docker --certfile path --certkeyfile path
Esto aplicará tu propio certificado SSL.